import json

    
def save_to_text(flashcards, file_name="flashcards.txt"):
    separator = "\t"

    text_output = ""
    # last_meaning = ""
    for word, flashcard in flashcards.items():
        text_output += f"{word}{separator}"
        for f in flashcard:
            # if f['meaning'] != last_meaning:
            #     text_output += f"{f['meaning']}<br>"
            text_output += "<ul>"
            for d in f['definitions']:
                text_output += f"<li>{d}</li>"
            text_output += "</ul>"

            # last_meaning = f['meaning']
            
        text_output += "\n"
        
    with open(file_name, "w", encoding='utf-8') as f:
        f.write(text_output)


if __name__ == "__main__":
    with open("flashcards.json", "r") as f:
        fl = json.load(f)
        
    save_to_text(fl)



import re
from wiktionaryparser import WiktionaryParser
import json
from tqdm import tqdm

from clippings2anki.flashcards import get_flashcard
from clippings2anki.anki import save_to_text


def main(input_file, language):
    #! read the clippings file
    with open(input_file, "r") as f:
        clippings = f.read()
    
    clip_re = re.compile(r"(.*)\n==========")
    
    # find all matches
    clips = clip_re.findall(clippings)
    
    clips_set = set()
    
    for clip in clips:
        if not clip:
            continue

        # remove punctuation from the clip
        clip = re.sub(r"[^\w\s]", "", clip)

        # print(clip)
        clips_set.add(clip)
        
    print(f"{len(clips_set)} clippings found")
    print()

    #! get the definitions of the words from wiktionary
    parser = WiktionaryParser()
    parser.set_default_language(language)
    
    flashcards = {}

    for i in tqdm(clips_set):
        word, f = get_flashcard(i, parser)
        
        if not word:
            continue
        
        flashcards[word] = f
    
    # save the flashcards to json file
    with open("flashcards.json", "w") as f:
        json.dump(flashcards, f, indent=4)
    print("flashcards saved to flashcards.json")
    
    #! save the flashcards to anki-friendly text file
    save_to_text(flashcards)
    print("flashcards saved to flashcards.txt")


if __name__ == "__main__":
    input_file = "Kindle My Clippings.txt"
    language = "english"
    
    main(input_file, language)



import sys
sys.path.append("")

import clippings2anki.clippings as clippings

if __name__ == "__main__":
    # read cli arguments
    import argparse
    parser = argparse.ArgumentParser()
    parser.add_argument("input_file", type=str)
    parser.add_argument("language", type=str)
    args = parser.parse_args()

    clippings.main(args.input_file, args.language)
